@@ -60,12 +60,9 @@ static unsigned char third_and_fourth_args_force_ref[] =
 function_entry clamav_functions[] = {
 	PHP_FE(cl_info, NULL)
 	PHP_FE(cl_scanfile, NULL)
-	PHP_FE(cl_scanbuff, NULL)
 	PHP_FE(cl_setlimits, NULL)
 	PHP_FE(cl_scanfile_ex, third_and_fourth_args_force_ref)
-	PHP_FE(cl_scanbuff_ex, third_and_fourth_args_force_ref)
 	PHP_FE(cl_pretcode, NULL)
-	PHP_FE(clam_scan_buffer, NULL)	/* compatibility */
 	PHP_FE(clam_scan_file, NULL)    /* compatibility */
 	PHP_FE(clam_get_version, NULL)  /* compatibility */
 	{NULL, NULL, NULL}				/* Must be the last line in clamav_functions[] */
@@ -145,7 +142,7 @@ PHP_MINIT_FUNCTION(clamav)
 
 	/* database loading */
 	if ((ret = cl_loaddbdir(CLAMAV_G(dbpath), &root, &sig_num))) {
-		php_error(E_WARNING, "cl_loaddbdir: %s\n", cl_perror(ret));
+		php_error(E_WARNING, "cl_loaddbdir: failed\n");
 		return FAILURE;
 	}
 
@@ -177,8 +174,6 @@ PHP_MINIT_FUNCTION(clamav)
 							CONST_CS | CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("CL_SCAN_MAIL", CL_SCAN_MAIL, 
 							CONST_CS | CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("CL_SCAN_DISABLERAR", CL_SCAN_DISABLERAR, 
-							CONST_CS | CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("CL_SCAN_OLE2", CL_SCAN_OLE2, 
 							CONST_CS | CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("CL_SCAN_BLOCKENCRYPTED", CL_SCAN_BLOCKENCRYPTED, 
@@ -213,8 +208,6 @@ PHP_MINIT_FUNCTION(clamav)
                             CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("CL_EZIP", CL_EZIP,
                             CONST_CS | CONST_PERSISTENT);
-    REGISTER_LONG_CONSTANT("CL_EMALFZIP", CL_EMALFZIP,
-                            CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("CL_EGZIP", CL_EGZIP,
                             CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("CL_EBZIP", CL_EBZIP,
@@ -370,40 +363,6 @@ static void php_cl_scanfile(INTERNAL_FUNCTION_PARAMETERS, int compat)
 
 /* }}} */
 
-/* {{{ php_cl_scanbuff() */
-
-static void php_cl_scanbuff(INTERNAL_FUNCTION_PARAMETERS, int compat)
-{
-    const int NUM_ARGS = 1;
-    char *buffer;       /* buffer to be scanned */
-    int buffer_len; 	/* length of the string */
-    int ret;            /* clamav functions return value */
-    const char *virname;
-
-    /* argument checking */
-    if (ZEND_NUM_ARGS() != NUM_ARGS) {
-        WRONG_PARAM_COUNT;
-        return FAILURE;
-    }
-    /* argument parsing */
-    if (zend_parse_parameters(NUM_ARGS TSRMLS_CC, "s", &buffer, &buffer_len) == FAILURE) {
-        return FAILURE;
-    }
-
-    ret = cl_scanbuff(buffer, buffer_len, &virname, root);
- 
-    if (ret == CL_VIRUS) {
-        RETURN_STRINGL((char *)virname,strlen(virname),1);
-    } else if (ret == CL_CLEAN) {
-        if (compat == 0) RETURN_NULL() else RETURN_FALSE;
-    } else {
-        php_error(E_WARNING,"error: %s", cl_strerror(ret));
-        if (compat == 0) RETURN_NULL() else RETURN_FALSE;
-    }
-}
-
-/* }}} */
-
 /* {{{ php_cl_info() */
 
 static void php_cl_info(INTERNAL_FUNCTION_PARAMETERS, int compat)
@@ -440,16 +399,6 @@ PHP_FUNCTION(cl_scanfile)
 
 /* }}} */
 
-/* {{{ proto string cl_scanbuff(string buffer)
-   Scans a buffer, given a string (buffer). This function is not fully tested */
-
-PHP_FUNCTION(cl_scanbuff)
-{
-	php_cl_scanbuff(INTERNAL_FUNCTION_PARAM_PASSTHRU, 0);
-}
-
-/* }}} */
-
 /* {{{ proto void cl_setlimits(int maxfiles, int maxfilesize, int maxreclevel, 
 							   int maxratio, int archivememlim) 
    Set the ClamAV limits for scanning */ 
@@ -547,62 +496,6 @@ PHP_FUNCTION(cl_scanfile_ex)
 
 /* }}} */
 
-/* {{{ proto int cl_scanbuff_ex(string buff, int buffsize, string virusname, 
-								 int retcode) 
-   Scans a buffer, given a string buffer.It returns the virus name 
-   (if it was found) and the ClamAV return code */
-
-PHP_FUNCTION(cl_scanbuff_ex) 
-{
-	/* number of arguments */
-	const int NUM_ARGS	= 4;
-
-	/* parameters */
-	zval *buff;
-	zval *buff_size;
-	zval *virusname;
-	zval *retcode;
-
-	/* used for cl_scanfile function */
-	char *virname	= NULL;
-	int ret;
-
-	if (ZEND_NUM_ARGS() != NUM_ARGS) {
-		WRONG_PARAM_COUNT;
-		RETURN_FALSE;
-	}
-	
-	/* parameters parsing */	
-	if (zend_parse_parameters(NUM_ARGS TSRMLS_CC, "zzzz", &buff, &buff_size,  &virusname, 
-							   &retcode) != SUCCESS) {
-		WRONG_PARAM_COUNT;
-		RETURN_FALSE;
-	}
-
-	/* parameter conversion */
-	convert_to_string_ex(&buff);
-	convert_to_long_ex(&buff_size);
-	
-	/* clean up old values first */
-	zval_dtor(virusname);	
-	zval_dtor(retcode);
-	
-	/* executing the ClamAV virus checking function */
-    ret = cl_scanbuff(Z_STRVAL_P(buff), Z_LVAL_P(buff_size), 
-					  &virname, root);
-
-	/* copy the value of the cl_scanfile return value */	
-	ZVAL_LONG(retcode, ret);
-	
-	/* copy the value of the cl_scanfile virusname if a virus was found */
-	if (ret == CL_VIRUS) 
-		ZVAL_STRING(virusname, virname, 1);
-
-	RETURN_TRUE;
-}
-
-/* }}} */
-
 /* {{{ proto string cl_pretcode(int retcode)
    Translates the ClamAV return code */
 
@@ -637,9 +530,6 @@ PHP_FUNCTION(cl_pretcode)
 		case CL_EZIP:
 			RETURN_STRING("zip handler error", 1);
 			break;
-		case CL_EMALFZIP:
-			RETURN_STRING("malformed zip", 1);
-			break;
 		case CL_EGZIP:
 			RETURN_STRING("gzip handler error", 1);
 			break;
@@ -712,15 +602,6 @@ PHP_FUNCTION(cl_pretcode)
 
 /* compatibility functions */
 
-/* {{{ proto string clam_scan_buffer($buffer) */
-PHP_FUNCTION(clam_scan_buffer)
-{
-	php_cl_scanbuff(INTERNAL_FUNCTION_PARAM_PASSTHRU, 1);
-	return SUCCESS;
-}
-
-/* }}} */
-
 /* {{{ proto string clam_scan_file($filename) */
 
 PHP_FUNCTION(clam_scan_file)
